==========================
Qtile |travis| |coveralls|
==========================

A full-featured, pure-Python tiling window manager
==================================================

:Website: http://www.qtile.org
:Source: https://github.com/qtile/qtile
:Documentation: http://qtile.readthedocs.org/en/latest/
:License: MIT License

Features
========

* Simple, small and extensible. It's easy to write your own layouts,
  widgets and commands.
* Configured in Python.
* Command shell that allows all aspects of Qtile to be managed and
  inspected.
* Complete remote scriptability - write scripts to set up workspaces,
  manipulate windows, update status bar widgets and more.
* Qtile's remote scriptability makes it one of the most thoroughly
  unit-tested window managers around.

Current Release
===============

The current stable version of qtile is 0.10.2, released 2015-10-18. See the
`documentation <http://docs.qtile.org/en/latest/manual/install/index.html>`_
for installation instructions.

Community
=========

Qtile is supported by a dedicated group of users. If you need any help, please
don't hesitate to fire off an email to our mailing list or join us on IRC.

:Mailing List: http://groups.google.com/group/qtile-dev
:IRC: irc://irc.oftc.net:6667/qtile

Contributing
============

Please report any suggestions, feature requests, bug reports, or annoyances to
the Github `issue tracker`_. There are also a few `tips, tricks, and guidelines
<http://docs.qtile.org/en/latest/manual/hacking.html>`_ for contributing in the
documentation.

.. _`issue tracker`: https://github.com/qtile/qtile/issues

.. |travis| image:: https://travis-ci.org/qtile/qtile.svg?branch=develop
    :alt: Build Status
    :target: https://travis-ci.org/qtile/qtile
.. |coveralls| image:: https://coveralls.io/repos/qtile/qtile/badge.png?branch=develop
    :alt: Build Coverage
    :target: https://coveralls.io/r/qtile/qtile
